//! ### Inputs/Outputs
//!
//! Inputs/Outputs create a Rust variable with type [`Expr<T>`] where `T` is the type of the input/output.
//!
//! Inputs/Outputs follow [connection semantics], which are unlike assignments in software,
//! so you should read it.
//!
//! ```
//! # use fayalite::{hdl_module, int::UInt, expr::Expr, array::Array};
//! # #[hdl_module]
//! # fn module() {
//! #[hdl]
//! let my_input: UInt<10> = m.input();
//! let _: Expr<UInt<10>> = my_input; // my_input has type Expr<UInt<10>>
//! #[hdl]
//! let my_output: Array<[UInt<10>; 3]> = m.output();
//! # }
//! ```
//!
//! [connection semantics]: crate::_docs::semantics::connection_semantics

#[allow(unused)]
use crate::expr::Expr;
