//! ### Wires
//!
//! Wires are kinda like variables, but unlike registers,
//! they have no memory (they're combinatorial).
//! You must [connect][`ModuleBuilder::connect`] to all wires, so they have a defined value.
//!
//! Wires create a Rust variable with type [`Expr<T>`] where `T` is the type of the wire.
//!
//! Wires follow [connection semantics], which are unlike assignments in software, so you should read it.
//!
//! ```
//! # use fayalite::{hdl_module, int::UInt, array::Array, clock::ClockDomain};
//! # #[hdl_module]
//! # fn module() {
//! # #[hdl]
//! # let v: UInt<1> = m.input();
//! #[hdl]
//! let my_wire: UInt<8> = m.wire();
//! #[hdl]
//! if v {
//!     m.connect(my_wire, 0x45_hdl_u8);
//! } else {
//!     // wires must be connected to under all conditions
//!     m.connect(my_wire, 0x23_hdl_u8);
//! }
//! # }
//! ```
//!
//! [connection semantics]: crate::_docs::semantics::connection_semantics

#[allow(unused)]
use crate::{expr::Expr, module::ModuleBuilder};
