//! # `#[hdl]` Struct/Variant Expressions
//!
//! Note: Structs are also known as [Bundles] when used in Fayalite, the Bundle name comes from [FIRRTL].
//!
//! [Bundles]: crate::bundle::BundleValue
//! [FIRRTL]: https://github.com/chipsalliance/firrtl-spec
//!
//! `#[hdl]` can be used on Struct/Variant Expressions to construct a value of that
//! struct/variant's type. They can also be used on tuples.
//!
//! ```
//! # use fayalite::{hdl_module, int::UInt, array::Array, ty::Value};
//! #[derive(Value, Clone, PartialEq, Eq, Hash, Debug)]
//! #[hdl(fixed_type)]
//! pub struct MyStruct {
//!     pub a: UInt<8>,
//!     pub b: UInt<16>,
//! }
//!
//! #[derive(Value, Clone, PartialEq, Eq, Hash, Debug)]
//! pub enum MyEnum {
//!     A,
//!     B {
//!         v: UInt<32>,
//!     },
//! }
//!
//! # #[hdl_module]
//! # fn module() {
//! #[hdl]
//! let v: UInt<8> = m.input();
//! #[hdl]
//! let my_struct: MyStruct = m.wire();
//! m.connect(
//!     my_struct,
//!     #[hdl]
//!     MyStruct {
//!         a: v,
//!         b: 1234_hdl_u16,
//!     },
//! );
//! #[hdl]
//! let my_enum: MyEnum = m.wire();
//! m.connect(
//!     my_enum,
//!     #[hdl]
//!     MyEnum::B { v: 12345678_hdl_u32 },
//! );
//! #[hdl]
//! let some_tuple: (UInt<4>, UInt<12>) = m.wire();
//! m.connect(
//!     some_tuple,
//!     #[hdl]
//!     (12_hdl_u4, 3421_hdl_u12),
//! );
//! # }
//! ```

#[allow(unused)]
use crate::array::Array;
